openvox.jruby-utils.jruby-defaults

Requiring this namespace has one side-effect: it sets Java properties read by JRuby settings in order to change default behavior, while retaining the ability for users to explicitly overrride settings via JAVA_ARGS.

This namespace should be required very early in the application lifecycle, before any classes are imported from org.jruby, as some properties are read once during class initialization and then never consulted again.

Requiring this namespace has one side-effect: it sets Java properties
read by JRuby settings in order to change default behavior, while retaining
the ability for users to explicitly overrride settings via JAVA_ARGS.

This namespace should be required very early in the application lifecycle,
before any classes are imported from org.jruby, as some properties are read
once during class initialization and then never consulted again.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries