openvox.jruby-utils.jruby-defaults

Requiring this namespace has one side-effect: it sets Java properties read by JRuby settings in order to change default behavior, while retaining the ability for users to explicitly overrride settings via JAVA_ARGS.

This namespace should be required very early in the application lifecycle, before any classes are imported from org.jruby, as some properties are read once during class initialization and then never consulted again.

Requiring this namespace has one side-effect: it sets Java properties
read by JRuby settings in order to change default behavior, while retaining
the ability for users to explicitly overrride settings via JAVA_ARGS.

This namespace should be required very early in the application lifecycle,
before any classes are imported from org.jruby, as some properties are read
once during class initialization and then never consulted again.
raw docstring

defaultsclj

Map of String->String indicating defaults to set in JVM properties that influence JRuby behavior.

Map of String->String indicating defaults to set in JVM properties that
influence JRuby behavior.
sourceraw docstring

defaults-set-on-loadclj

source

set-jruby-property-defaults!clj

(set-jruby-property-defaults!)

Loop over the defaults map and set each in Java properties, if not already set by some other mechanism like a -D flag. Return a map of properties set in this way.

Loop over the defaults map and set each in Java properties, if not already
set by some other mechanism like a `-D` flag. Return a map of properties
set in this way.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries